#!/bin/bash
# Porter here, I'm going to add some comments so that you can tell what each part of this is doing.
# Hopefully, that will help us improve this script so that it does everything you need :)

# SETTINGS
# This are files I got from Emmett, my understanding is that these are all artifacts produced by qiime.
INPUT_FEATURE_QZA="Iceland-2019-trees-otu-table.qza"
INPUT_TAX_QZA="Iceland-2019-trees-run1-taxonomy-silva.qza"
INPUT_TREE_QZA="Iceland-2019-trees-rooted-tree.qza"

OUTPUT_FEATURE_TABLE="FEATURE_TABLE.biom"
OUTPUT_FEATURE_TEXT="FEATURE_TABLE.tsv"


# UNZIP QZA
qiime tools export --input-path $INPUT_TAX_QZA --output-path tax-extracted
qiime tools export --input-path $INPUT_FEATURE_QZA --output-path otu-table-extracted
qiime tools export --input-path $INPUT_TREE_QZA --output-path tree-extracted

# MODIFY HEADER TABLE
# We need to edit the header row on the taxonomy TSV file to some very specific values.
# A SED command can do this automatically:
HEADER="#OTUID	taxonomy	confidence"
sed -i "1s/.*/$HEADER/" tax-extracted/taxonomy.tsv


mkdir OUTPUT

# ADD ROW TO FEATURE TABLE (BIOM FILE)
# This is the really important part, where the information from the taxonomy table is added to the feature table.
# This seems to be working, but we won't know for sure until we can verify that in phyloseq.
biom add-metadata -i otu-table-extracted/feature-table.biom -o OUTPUT/$OUTPUT_FEATURE_TABLE --observation-metadata-fp tax-extracted/taxonomy.tsv --sc-separated taxonomy


# CREATE TSV COPY OF OUTPUT
# This part isn't really necissary, it just creates a TSV copy of the modified feature table.
# Useful since you can open the TSV in a text editor, and verify that it has the taxonomy column as it should.
biom convert -i OUTPUT/$OUTPUT_FEATURE_TABLE -o OUTPUT/$OUTPUT_FEATURE_TEXT --header-key taxonomy --to-tsv 

echo "DONE!"